@@ -83,7 +83,7 @@ enum { METERS_S, KILOMETERS_H, MILES_H };
 enum { CELSIUS, FAHRENHEIT };
 enum { INVALID_VALUE = 0, TINY, SMALL, MEDIUM, LARGE, GIANT };
 enum { ICON, STATION_NAME };
-enum { MB, INCH };
+enum { MB, INCH, MM };
 enum { WEATHER_COM1, WEATHER_COM2, RP5_RU, MAX_WEATHER_SOURCE_NUMBER };
 enum { TINY_ICON_SIZE = 32, SMALL_ICON_SIZE = 48, MEDIUM_ICON_SIZE = 64,
 	BIG_ICON_SIZE = 80, LARGE_ICON_SIZE = 96, GIANT_ICON_SIZE = 128,
@@ -127,7 +127,8 @@ enum { STATE_CELCIUS		= 1U,
        STATE_KILOMETERS_H	= 128U,
        STATE_MILES_H		= 256U,
        STATE_PRESSURE_MB	= 512U,
-       STATE_PRESSURE_IN	= 1024U
+       STATE_PRESSURE_IN	= 1024U,
+       STATE_PRESSURE_MM	= 2048U
 };
 /* update tab */
 enum { STATE_AUTO_CONNECT	= 1U,
@@ -246,8 +247,6 @@ typedef struct applet_config{
     gboolean	show_wind;
     GdkColor	font_color;
     GdkColor	background_color;
-    GdkColor	ui_background_color;
-    gboolean	ui_background_color_on;
 }AppletConfig;
 /*******************************************************************************/
 typedef struct OMWeatherApplet{
@@ -312,6 +311,7 @@ typedef struct OMWeatherApplet{
     gint		ay;
     gint		aw;
     gint		ah;
+    GSList		*tab_of_window_popup;
 #ifdef OS2008
     guint		gps_id_connection;
     LocationGPSDevice 	*gps_device;
