@@ -437,28 +437,6 @@ read_config(AppletConfig *config){
 	g_free(tmp);
     }
 
-	/* Get value of switch  UI background. Default is FALSE. */
-	value = NULL;
-	value = gconf_client_get(gconf_client, GCONF_KEY_UI_BACKGROUND_COLOR_ON, NULL);
-	if(value){
-		config->ui_background_color_on = TRUE;
-    	gconf_value_free(value);
-	}
-	else
-    	config->ui_background_color_on = FALSE;
-
-    /* Get UI background color */
-    config->ui_background_color.red = 0xCCCC;
-    config->ui_background_color.blue = 0xCCCC;
-    config->ui_background_color.green = 0xCCCC;
-    /* Get background color. */
-    tmp = NULL;
-    tmp = gconf_client_get_string(gconf_client,
-        			    GCONF_KEY_WEATHER_BACKGROUND_COLOR, NULL);
-    if(!tmp || !gdk_color_parse(tmp, &(config->background_color)))
-         config->background_color = DEFAULT_FONT_COLOR; 
-    g_free(tmp);
-    tmp = NULL;
     #ifndef OS2008
 	/* Get Enable Transparency flag. Default is TRUE. */
 	value = gconf_client_get(gconf_client, GCONF_KEY_ENABLE_TRANSPARENCY, NULL);
@@ -500,11 +478,12 @@ read_config(AppletConfig *config){
         config->sensor_update_time = 0;
     /* start timer for read data from device temperature sensor */
     if(config->use_sensor){
-	read_sensor(0);
+	read_sensor(FALSE);
 	app->sensor_timer = g_timeout_add(config->sensor_update_time * 1000 * 60,
                                             (GtkFunction)read_sensor,
                                             GINT_TO_POINTER(1));
-    }
+    }else
+      app->sensor_timer = 0;
     /* Get value of transparence default 0 */
     config->alpha_comp = gconf_client_get_int(gconf_client,
                 			    GCONF_KEY_ALPHA_COMPONENT,
@@ -611,7 +590,7 @@ read_config(AppletConfig *config){
     config->pressure_units = gconf_client_get_int(gconf_client,                                                                                     
                 				    GCONF_KEY_WEATHER_PRESSURE_UNITS,
 						    &gerror);
-    if(gerror || config->pressure_units > INCH){
+    if(gerror || config->pressure_units < MB || config->pressure_units > MM){
 	config->pressure_units = MB;
 	g_error_free(gerror);
     }
@@ -796,18 +775,6 @@ config_save(AppletConfig *config){
     gconf_client_set_string(gconf_client,
         		    GCONF_KEY_WEATHER_FONT,
 			    config->font, NULL);
-     /* Save UI Background color state */
-    gconf_client_set_bool(gconf_client,
-        		GCONF_KEY_UI_BACKGROUND_COLOR_ON,
-			    config->ui_background_color_on, NULL);
-    /* Save Background Color */
-    sprintf(temp_buffer, "#%02x%02x%02x",
-            config->background_color.red >> 8,
-            config->background_color.green >> 8,
-            config->background_color.blue >> 8);
-    gconf_client_set_string(gconf_client,
-        		    GCONF_KEY_WEATHER_BACKGROUND_COLOR,
-			    temp_buffer, NULL);
     /* Save Weather Update setting  */
     gconf_client_set_int(gconf_client,
         		    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
