@@ -335,16 +335,15 @@ gboolean download_html(gpointer data){
     START_FUNCTION;
 #endif
     if(app->popup_window && app->show_update_window){
-	gtk_widget_destroy(app->popup_window);
-	app->popup_window = NULL;
+        destroy_popup_window();
     }
     /* If not connected and it autoupdate do go away */
     if(!app->show_update_window && !app->iap_connected){
-    	app->flag_updating = 0;
-	return FALSE;
+        app->flag_updating = 0;
+        return FALSE;
     }
-    if(app->iap_connected) 
-	second_attempt = TRUE;
+    if(app->iap_connected)
+        second_attempt = TRUE;
 
 /* Connection wake up */    
     if( app->show_update_window && (!second_attempt) && (!app->iap_connecting) ){    
@@ -485,7 +484,7 @@ gboolean download_html(gpointer data){
 			    hildon_banner_show_information(app->main_window,
 							    NULL,
 							    _("Weather updated"));
-        		redraw_home_window(FALSE);	
+        		redraw_home_window(FALSE);
 		    }
 		    else{
 			valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list),
