@@ -29,9 +29,9 @@
 #define _weather_locations_h 1
 /*******************************************************************************/
 #include "weather-common.h"
-
-GtkListStore* create_items_list(const char *filename, long start, long end,
-				long *items_number);
+/*******************************************************************************/
+GtkListStore* create_items_list(const char *path, const char *filename,
+				long start, long end, long *items_number);
 int parse_country_string(const char *string, Country_item *result);
 int parse_region_string(const char *string, Region_item *result);
 int parse_station_string(const char *string, Station *result);
